@@ -5,6 +5,7 @@
 #-------------------------------------------------------------------------------
 
 package Data::Table::Text;
+require v5.16.0;
 use warnings FATAL => qw(all);
 use strict;
 use Carp;
@@ -13,6 +14,8 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
+our $VERSION = '2017.109';
+
 #-------------------------------------------------------------------------------
 # Current date and time
 #-------------------------------------------------------------------------------
@@ -300,12 +303,13 @@ sub checkKeys($$)
   delete @parms{$_} for keys %$permitted;
   return '' unless keys %parms;                                                 # Success - all the keys in the test hash are permitted
 
-  join "\n",                                                                    # Failure - explain what went wrong
+  confess join "\n",                                                            # Failure - explain what went wrong
    "Invalid options chosen:",
     indentString(formatTable([sort keys %parms]), '  '),
    "",
    "Permitted options are:",
-    indentString(formatTable($permitted),         '  ');
+    indentString(formatTable($permitted),         '  '),
+   "",
  }
 
 #-------------------------------------------------------------------------------
@@ -381,7 +385,7 @@ sub extractDocumentation()
  {my %methodParms;                                                              # Method names including parameters
   my %methods;                                                                  # Method names not including parameters
   my @d;                                                                        # Documentation
-  my $level = 0; my $off = 1;                                                   # Header levels
+  my $level = 0; my $off = 0;                                                   # Header levels
   my @l = split /\n/, readFile($0);                                             # Read this file
   for my $l(keys @l)
    {my $L = $l[$l];                                                             # This line
@@ -410,12 +414,17 @@ sub extractDocumentation()
       my $N = "$n($P)";                                                         # Method
       $methodParms{$N}++;                                                       # Method names including parameters
       $methods{$n}++;                                                           # Method names not including parameters
-      push @d, "\n=head$h $N\n\n $D\n";                                         # Method description
+      push @d, "\n=head$h $N\n\n$D\n";                                          # Method description
       push @d, indentString(formatTable([[qw(Parameter Description)], map{[$p[$_], $c[$_]]} keys @p]), '  ')
-        if $p and $c and $c !~ /\A#/;
+        if $p and $c and $c !~ /\A#/;                                           # Add parameter description if present
      }
    }
-  push @d, "\n\n=head$off Index of methods by name\n";                          # Index
+  push @d, <<END;                                                               # Index
+
+=head1 Index
+
+The following methods will be exported by the :all tag:
+END
   push @d, "L</$_>" for sort keys %methodParms;                                 # Alphabetic listing of methods
   push @d, "\n";
   writeFile("doc.data",     join "\n", @d);                                     # Write documentation file
@@ -440,19 +449,22 @@ if (0 and !caller)
 # Test
 #-------------------------------------------------------------------------------
 
-eval join('', <Data::Table::Text::DATA>) || die $@ unless caller();
+sub test
+ {eval join('', <Data::Table::Text::DATA>) || die $@
+ }
+
+test unless caller();
+
+# Documentation
+#extractDocumentation unless caller;
 
 #-------------------------------------------------------------------------------
 # Export
 #-------------------------------------------------------------------------------
 
-require 5;
 require Exporter;
 
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
-
-#say STDERR formatTable(\%Data::Table::Text::);
- extractDocumentation unless caller;                                            # Should be applied to this file
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @ISA          = qw(Exporter);
 @EXPORT       = qw(formatTable);
@@ -465,9 +477,6 @@ makePath nws
 readBinaryFile readFile timeStamp trim writeBinaryFile writeFile);
 %EXPORT_TAGS  = (all=>[@EXPORT, @EXPORT_OK]);
 
-#$VERSION = '1.007'; # Sunday 18 December 2016
- $VERSION = '1.008'; # Friday 30 December 2016
-
 1;
 
 =encoding utf-8
@@ -635,10 +644,13 @@ if (1)
  }
 
 if (1)                                                                          # CheckKeys, nsw
- {my $s = checkKeys({qw(go 1 Went 2 gone 3)},
-                    {qw(go present went past gone presentPast)}) =~ s/\n/|/gr;
+ {eval {checkKeys({qw(go 1 Went 2 gone 3)},
+                  {qw(go present went past gone presentPast)})};
+  my $s = $@;
+     $s =~ s/\s*at.*\Z//s;
+     $s =~ s/\n/|/g;
   my $S = 'Invalid options chosen:|  Went  ||Permitted options are:|  go    present      |  gone  presentPast  |  went  past         ';
-  ok $s eq $S;
+  ok nws($s) eq nws($S);
  }
 
 if (1)                                                                          # AL
